pub enum BusyBehavior {
Queue,
Wait,
Steer,
Fail,
}Expand description
What an agent call does when the conversation it continues is running
a turn, or has prompts queued (agent.on_busy).
Variants
Queue
Queue the prompt as a background job that runs after the turns ahead.
Wait
Keep the call waiting until the turns ahead end, then run it.
Steer
Add the prompt to the running turn when the agent’s ACP server can be
steered, otherwise apply BusyConfig::steer_fallback.
Fail
Refuse the call as busy.